pub enum LogicalBlockAssignmentError<T: BlockMetadata> {
DuplicateBlockId {
block_id: BlockId,
blocks: Vec<MutableBlock<T>>,
},
DuplicateAssignedBlockId {
block_id: BlockId,
blocks: Vec<ImmutableBlock<T>>,
},
SequenceHashMismatch {
position: usize,
expected: SequenceHash,
actual: SequenceHash,
blocks: Vec<ImmutableBlock<T>>,
},
}Expand description
Error type for LogicalBlockAssignments operations.
Variants
DuplicateBlockId
A mutable block_id in the input already exists in one of the three collections.
Fields

blocks: Vec<MutableBlock<T>>All input blocks returned for recovery (no leaks).
DuplicateAssignedBlockId
An immutable block_id in the input already exists in one of the three collections.
Fields

blocks: Vec<ImmutableBlock<T>>All input blocks returned for recovery (no leaks).
SequenceHashMismatch
A matched block’s sequence hash does not match the expected sequence hash.
Fields

expected: SequenceHashThe expected hash from the token sequence.

actual: SequenceHashThe actual hash from the matched block.

blocks: Vec<ImmutableBlock<T>>All input blocks returned for recovery (no leaks).