CompleteBlock

Struct CompleteBlock 

pub struct CompleteBlock<T: BlockMetadata> { /* private fields */ }
RAII guard for a block in the Staged state.

Implementations

Source

impl<T: BlockMetadata + Sync> CompleteBlock<T>

pub fn block_id(&self) -> BlockId

Returns the BlockId assigned to this block.

pub fn block_size(&self) -> usize

Returns the fixed block size of this block in tokens.

pub fn sequence_hash(&self) -> SequenceHash

Returns the SequenceHash assigned during staging.

pub fn reset(self) -> MutableBlock<T>

Roll back to a MutableBlock.