pub struct CompleteBlock<T: BlockMetadata> { /* private fields */ }Expand description
RAII guard for a block in the Staged state.
Implementations
Sourceimpl<T: BlockMetadata + Sync> CompleteBlock<T>
impl<T: BlockMetadata + Sync> CompleteBlock<T>
Sourcepub fn block_size(&self) -> usize
pub fn block_size(&self) -> usize
Returns the fixed block size of this block in tokens.
Sourcepub fn sequence_hash(&self) -> SequenceHash
pub fn sequence_hash(&self) -> SequenceHash
Returns the SequenceHash assigned during staging.
Sourcepub fn reset(self) -> MutableBlock<T>
pub fn reset(self) -> MutableBlock<T>
Roll back to a MutableBlock.